==> camel-k-sources-1.12.1.tar.gz: camel-k-1.12.1/pkg/cmd/operator.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package cmd

import (
	"github.com/apache/camel-k/pkg/platform"
	"github.com/apache/camel-k/pkg/util/defaults"
	"github.com/spf13/cobra"

	"github.com/apache/camel-k/pkg/cmd/operator"
)

const operatorCommand = "operator"

func newCmdOperator() (*cobra.Command, *operatorCmdOptions) {
	options := operatorCmdOptions{}

	cmd := cobra.Command{
		Use:     "operator",
		Short:   "Run the Camel K operator",
		Long:    `Run the Camel K operator`,
		Hidden:  true,
		PreRunE: decode(&options),
		Run:     options.run,
	}

	cmd.Flags().Int32("health-port", 8081, "The port of the health endpoint")
	cmd.Flags().Int32("monitoring-port", 8080, "The port of the metrics endpoint")
	cmd.Flags().Bool("leader-election", true, "Use leader election")
	cmd.Flags().String("leader-election-id", "", "Use the given ID as the leader election Lease name")

	return &cmd, &options
}

type operatorCmdOptions struct {
	HealthPort       int32  `mapstructure:"health-port"`
	MonitoringPort   int32  `mapstructure:"monitoring-port"`
	LeaderElection   bool   `mapstructure:"leader-election"`
	LeaderElectionID string `mapstructure:"leader-election-id"`
}

func (o *operatorCmdOptions) run(_ *cobra.Command, _ []string) {

	leaderElectionID := o.LeaderElectionID
	if leaderElectionID == "" {
		if defaults.OperatorID() != "" {
			leaderElectionID = platform.GetOperatorLockName(defaults.OperatorID())
		} else {
			leaderElectionID = platform.OperatorLockName
		}
	}

	operator.Run(o.HealthPort, o.MonitoringPort, o.LeaderElection, leaderElectionID)
}

==> camel-k-sources-2.2.0.tar.gz: camel-k-2.2.0/pkg/cmd/operator.go <==
/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package cmd

import (
	"github.com/apache/camel-k/v2/pkg/platform"
	"github.com/apache/camel-k/v2/pkg/util/defaults"
	"github.com/spf13/cobra"

	"github.com/apache/camel-k/v2/pkg/cmd/operator"
)

const operatorCommand = "operator"

func newCmdOperator() (*cobra.Command, *operatorCmdOptions) {
	options := operatorCmdOptions{}

	cmd := cobra.Command{
		Use:     "operator",
		Short:   "Run the Camel K operator",
		Long:    `Run the Camel K operator`,
		Hidden:  true,
		PreRunE: decode(&options),
		Run:     options.run,
	}

	cmd.Flags().Int32("health-port", 8081, "The port of the health endpoint")
	cmd.Flags().Int32("monitoring-port", 8080, "The port of the metrics endpoint")
	cmd.Flags().Bool("leader-election", true, "Use leader election")
	cmd.Flags().String("leader-election-id", "", "Use the given ID as the leader election Lease name")

	return &cmd, &options
}

type operatorCmdOptions struct {
	HealthPort       int32  `mapstructure:"health-port"`
	MonitoringPort   int32  `mapstructure:"monitoring-port"`
	LeaderElection   bool   `mapstructure:"leader-election"`
	LeaderElectionID string `mapstructure:"leader-election-id"`
}

func (o *operatorCmdOptions) run(_ *cobra.Command, _ []string) {

	leaderElectionID := o.LeaderElectionID
	if leaderElectionID == "" {
		if defaults.OperatorID() != "" {
			leaderElectionID = platform.GetOperatorLockName(defaults.OperatorID())
		} else {
			leaderElectionID = platform.OperatorLockName
		}
	}

	operator.Run(o.HealthPort, o.MonitoringPort, o.LeaderElection, leaderElectionID)
}
